@@ -23,7 +23,7 @@ from os import path
 from calculate.core.server.core_interfaces import MethodsInterface
 from calculate.lib.utils.files import (makeDirectory, removeDir, tar_directory,
                                        FilePermission, find, listDirectory,
-                                       FilesError, process,
+                                       FilesError, process, readFileEx,
                                        readFile, pathJoin, FindFileType)
 from calculate.lib.utils.content import FileOwnersRestricted, ContentsStorage
 from calculate.lib.utils.portage import getInstalledAtom, makeCfgName
@@ -283,8 +283,8 @@ class Backup(MethodsInterface):
         try:
             for fn in find(source_etc_dn, filetype=FindFileType.RegularFile):
                 if (not reCfg.search(fn) and
-                            " Modified Calculate" in readFile(fn,
-                                                              headbyte=300)):
+                            " Modified Calculate" in readFileEx(fn,
+                                                                headbyte=300)):
                     self.backup_file(fn, root_dn, prefix=source_dn)
         except (OSError, IOError) as e:
             raise BackupError(_("Failed to backup configuration files that "
