@@ -41,9 +41,9 @@ class GotErrorField(Exception):
 
 
 class BoolAction(argparse.Action):
-    reTrue = re.compile("^(?:on)$", re.I)
-    reFalse = re.compile("^(?:off)$", re.I)
-    available_values = ("on", "off")
+    reTrue = re.compile("^(?:on|yes)$", re.I)
+    reFalse = re.compile("^(?:off|no)$", re.I)
+    available_values = ("on", "off","yes", "no")
 
     def __init__(self, option_strings, dest, nargs="?",
                  const=None, default=None, type=None, choices=None,
@@ -66,6 +66,10 @@ class BoolAction(argparse.Action):
         if values is None:
             values = "on"
         else:
+            if self.reTrue.match(values):
+                values = "on"
+            if self.reFalse.match(values):
+                values = "off"
             values = self.get_values(values)
             if not values:
                 msg = _('the value may be {0}').format(
@@ -74,7 +78,7 @@ class BoolAction(argparse.Action):
         setattr(ns, self.dest, values)
 
 class BoolAutoAction(BoolAction):
-    available_values = ("on", "off", "auto")
+    available_values = ("on", "off", "yes", "no", "auto")
 
 def _print(*args):
     print " ".join(map(lambda x: _u8(x), args))
