@@ -78,18 +78,18 @@ class ClApplication(Application):
             os.system('mkdir %s' % server.sids)
 
         if not os.path.isfile(server.sids_file):
-            open(server.sids_file, 'w')
-        fd = open(server.sids_file, 'r')
-        while 1:
-            try:
-                # read all on one record
-                list_sid = pickle.load(fd)
-            except (IOError, EOFError, KeyError):
-                break
-            # find session id in sids file
-            if cert_id == int(list_sid[1]):
-                if int(sid) == int(list_sid[0]):
-                    return 1
+            open(server.sids_file, 'w').close()
+        with open(server.sids_file, 'r') as fd:
+            while 1:
+                try:
+                    # read all on one record
+                    list_sid = pickle.load(fd)
+                except (IOError, EOFError, KeyError):
+                    break
+                # find session id in sids file
+                if cert_id == int(list_sid[1]):
+                    if int(sid) == int(list_sid[0]):
+                        return 1
         return 0
 
     # input parameters - certificate and name method
@@ -131,11 +131,13 @@ class ClApplication(Application):
                 if not self.check_cert_sid(params.sid, curthread.server):
                     return 0
 
-        data_server_cert = open(server_cert, 'r').read()
+        with open(server_cert, 'r') as f:
+            data_server_cert = f.read()
         certobj = OpenSSL.crypto.load_certificate(
             OpenSSL.SSL.FILETYPE_PEM, data_server_cert)
 
-        data_server_key = open(server_key, 'r').read()
+        with open(server_key, 'r') as f:
+            data_server_key = f.read()
         Pkey = OpenSSL.crypto.load_privatekey(OpenSSL.SSL.FILETYPE_PEM,
                                               data_server_key, 'qqqq')
         signature = OpenSSL.crypto.sign(Pkey, cert, 'SHA1')
@@ -158,8 +160,7 @@ class ClApplication(Application):
         groups_list = groups.split(',')
         # open certificates database
         if not os.path.exists(certbase):
-            fc = open(certbase, "w")
-            fc.close()
+            open(certbase, "w").close()
         from cert_cmd import find_cert_id
 
         checked_id = find_cert_id(cert, data_path, certbase)
@@ -174,8 +175,8 @@ class ClApplication(Application):
             # if group = all and not redefined group all
             if 'all' in groups_list:
                 find_flag = False
-                fd = open(group_rights, 'r')
-                t = fd.read()
+                with open(group_rights, 'r') as fd:
+                    t = fd.read()
                 # find all in group_rights file
                 for line in t.splitlines():
                     if not line:
@@ -191,7 +192,7 @@ class ClApplication(Application):
                 try:
                     # check rights
                     if not os.path.exists(rights):
-                        open(rights, 'w')
+                        open(rights, 'w').close()
                     with open(rights) as fr:
                         t = fr.read()
                         for line in t.splitlines():
@@ -218,7 +219,7 @@ class ClApplication(Application):
                         break
                     # open file with groups rights
                     if not os.path.exists(group_rights):
-                        open(group_rights, 'w')
+                        open(group_rights, 'w').close()
                     with open(group_rights) as fd:
                         t = fd.read()
                         for line in t.splitlines():
@@ -270,10 +271,10 @@ class ClApplication(Application):
             os.makedirs(data_path + '/conf')
 
         if not os.path.exists(data_path + '/conf/right.conf'):
-            open(data_path + '/conf/right.conf', 'w')
+            open(data_path + '/conf/right.conf', 'w').close()
 
         if not os.path.exists(data_path + '/conf/group_right.conf'):
-            open(data_path + '/conf/group_right.conf', 'w')
+            open(data_path + '/conf/group_right.conf', 'w').close()
 
         if not os.path.exists(data_path + '/client_certs'):
             os.makedirs(data_path + '/client_certs')
